@@ -3,6 +3,7 @@ from jsonschema import Draft4Validator
 from jsonschema.compat import iteritems
 import json
 import codecs
+import copy
 import os.path
 import inflection
 import six
@@ -43,12 +44,26 @@ class ObjectBuilder(object):
             }
         )
 
+        meta_validator = Draft4Validator(Draft4Validator.META_SCHEMA)
+        meta_validator.validate(self.schema)
         self.validator = Draft4Validator(self.schema,
                                          resolver=self.resolver)
 
+
         self._classes = None
         self._resolved = None
 
+    @property
+    def schema(self):
+        try:
+            return copy.deepcopy(self._schema)
+        except AttributeError:
+            raise ValidationError("No schema provided")
+
+    @schema.setter
+    def schema(self, val):
+        setattr(self, '_schema', val)
+
     @property
     def classes(self):
         if self._classes is None:
